(function() {
	'use restrict';

	const myScript = document.scripts[document.scripts.length - 1];

	const PLUGIN = myScript.src.replace(/^.*\/(\w*)\.js$/, '$1');
	const BOOKMARK = '.pagination,#pagination,[class*="pagination"]';
	const PAGINATION_CONTAINER = document.body.querySelector(BOOKMARK);
	if(PAGINATION_CONTAINER == null || PAGINATION_CONTAINER.childElementCount == 0) {
		return;
	}

	const PROGRESS_BAR_CLASSNAME = '.' + PLUGIN + '-progress';
	const progressBar = PAGINATION_CONTAINER.querySelector(PROGRESS_BAR_CLASSNAME);
	if(progressBar == null) {
		console.error(PROGRESS_BAR_CLASSNAME + ' element is missing in ' + BOOKMARK + ' parentElement');
		return;
	}

	if (!'url' in progressBar.dataset) {
		console.error(PROGRESS_BAR_CLASSNAME + ' element has no data-url attribute');
		return;
	}

	const ART_QUERY = '.article[id^="post"]';
	const FIRST_ARTICLE = PAGINATION_CONTAINER.parentElement.querySelector(ART_QUERY);
	if(FIRST_ARTICLE == null) {
		console.error('No ' + ART_QUERY + ' element found');
		return;
	}

	const ARTS_CONTAINER = FIRST_ARTICLE.parentElement;
	PAGINATION_CONTAINER.classList.add(PLUGIN + '-navigation');

	const container = document.createElement('DIV');
	container.className = PLUGIN + '-container';
	document.body.appendChild(container);

	const SCROLL_LEVEL = 100;

	var loading = false;
	const XHR = new XMLHttpRequest();
	XHR.onreadystatechange = function(event) {
	    if (this.readyState === XMLHttpRequest.DONE) {
	        if (this.status !== 200) {
	            console.error("Status de la réponse: %d (%s)", this.status, this.statusText);
			}

			container.innerHTML = this.responseText;
			const articles = container.querySelectorAll(ART_QUERY);
			if (articles.length == 0) {
				progressBar.classList.add('noactive');
				loading = true;
				return;
			}

			Array.from(articles).forEach(function (el) {
				var art = el.parentElement.removeChild(el);
				ARTS_CONTAINER.appendChild(art);
			});

			const newProgressBar = container.querySelector(PROGRESS_BAR_CLASSNAME);
			if(newProgressBar != null) {
				progressBar.value = newProgressBar.value;
				if (progressBar.value < progressBar.max) {
					// On récupère l'Url pour la prochaine page d'articles
					progressBar.dataset.url = newProgressBar.dataset.url;
					// Il y a encore des pages à télécharger
					loading = false;
				} else {
					// Dernière page téléchargée
					progressBar.classList.add('noactive');
				}
			}

			// On élimine le reste de la page téléchargée
			container.textContent = '';
	    }
	}

	var timer1 = null;
	window.addEventListener('scroll', function(event) {
		if(!loading && timer1 == null) {
			timer1 = setTimeout(function() {
				const boundings = ARTS_CONTAINER.getBoundingClientRect();
				if(boundings.bottom - window.innerHeight < SCROLL_LEVEL) {
					if (progressBar.value < progressBar.max) {
						loading = true;
						const url = progressBar.dataset.url + '-' + PLUGIN.toUpperCase();
						console.log('url: %s', url);
						XHR.open('GET', url, true);
						XHR.send(null);
					}
				}
				// The job is done !
				clearTimeout(timer1);
				timer1 = null;
			}, 500);
		}
	});

	document.body.classList.add(PLUGIN);
})();
